@@ -8,30 +8,40 @@ SK.default <- function(x,
                        which, 
                        id.trim=3,
                        error,
-                       sig.level=.05, ...)
+                       sig.level=.05,
+                       dispersion=c('mm', 's', 'se'), ...)   
 {
   if (is.data.frame(y)) 
     y <- as.matrix(y[, 1])  # manova is not contemplated
   else
     stopifnot(is.atomic(y))
+
   if (is.matrix(x) || is.atomic(x))
     x <- as.data.frame(x)
+
   if(!is.null(y))
-    dat <- as.data.frame(cbind(x, y))
+    dat <- as.data.frame(cbind(x,
+                               y))
   else
     dat <- x
-  av <- eval(substitute(aov(fo, dat),
+
+  av <- eval(substitute(aov(fo,
+                            dat),
                         list(fo=formula(model))))
+
   if(class(av)[1] == 'aov')
     res <- SK.aov(x=av,
                   which=which,
                   id.trim=id.trim, 
-                  sig.level=sig.level)
+                  sig.level=sig.level,
+                  dispersion=dispersion)
   else
     res <- SK.aovlist(x=av,
                       which=which,
                       id.trim=id.trim, 
                       error=error,
-                      sig.level=sig.level)
+                      sig.level=sig.level,
+                      dispersion=dispersion)
+
   invisible(res)
 }
